@@ -7,7 +7,7 @@ use HTML::Template::Compiled::Expression qw(:expressions);
 use HTML::Template::Compiled::Utils qw(:walkpath);
 use File::Basename qw(dirname);
 
-our $VERSION = '1.001_002'; # VERSION
+our $VERSION = '1.002_001'; # TRIAL VERSION
 
 our $DISABLE_NEW_ALIAS = 0;
 
@@ -449,8 +449,8 @@ sub parse_var {
 
 sub dump_string {
     my ($self, $string) = @_;
-    my $dump = Data::Dumper->Dump([\$string], ['string']);
-    $dump =~ s#^\$string *= *\\##;
+    my $dump = HTML::Template::Compiled->dump_var($string, 'string');
+    $dump =~ s#^\$string *= *## or die "dump_string() failed";
     $dump =~ s/;$//;
     return $dump;
 }
@@ -816,8 +816,9 @@ EOM
 
                 my $join_code = '';
                 if (defined (my $join = $attr->{JOIN})) {
-                    my $dump = Data::Dumper->Dump([$join], ['join']);
-                    $dump =~ s{\$join = }{};
+                    my $dump = HTML::Template::Compiled->dump_var($join, 'join');
+                    $dump =~ s{\$join *= *}{};
+                    $dump =~ s{;$}{};
                     $join_code = <<"EOM";
 \{
   unless (\$__ix__ == \$[) \{
